@@ -1,5 +1,5 @@
 import csv
-from graphmanagerlib.Data_for_gcn import get_data
+from graphmanagerlib.Complex_Data_For_Gcn import get_data
 from graphmanagerlib.Model_formation import CreateTrainAndSaveGCN
 from graphmanagerlib.Inference import predictionsUnique
 
