@@ -3,7 +3,7 @@ import numpy as np
 import torch
 
 from graphmanagerlib.Complex_Graph import Grapher
-from graphmanagerlib.Data_for_gcn import getDataForUniquePrediction
+from graphmanagerlib.Complex_Data_For_Gcn import getDataForUniquePrediction
 from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects,ConvertPredictionToJson
 
 
