@@ -3,10 +3,9 @@ from graphmanagerlib.Node import Node
 from graphmanagerlib.Document import Document
 
 def GetJsonFromFile(jsonPath):
-    f = open(jsonPath, encoding="utf8")
-    result = json.load(f)
-    f.close()
-    return result
+    with open(jsonPath, encoding="utf8") as file:
+        reader = json.load(file)
+        return reader
 
 def ConvertJsonToDocumentsObjects(json):
     listOfDocuments = []
