@@ -58,11 +58,11 @@ def CreateTrainAndSaveGCN(train_data, test_data, saved_folder, nb_classes):
                 loss_val = F.nll_loss(model(test_data), (test_data.y - 1).long()
                 )
                 fmt_log = "Epoch: {:03d}, train_loss:{:.4f}, val_loss:{:.4f}"
-                print(fmt_log.format(epoch, loss, loss_val))
-                print(">" * 50)
+                print(fmt_log.format(epoch, loss, loss_val), flush=True)
+                print(">" * 50, flush=True)
 
     saved_model_path = os.path.join(saved_folder, "saved_model.pt")
     torch.save(model, saved_model_path)
 
-    print("===== Model train and save -> success =====")
+    print("===== Model train and save -> success =====", flush=True)
     return saved_model_path
